@@ -1,6 +1,8 @@
 context("Test MaxMind.")
 test_that("non-existent files are detected", {
-  expect_that(maxmind("foo","[@8"), throws_error("could not be opened"))
+  suppressWarnings({
+    expect_that(maxmind("foo","bar"), throws_error("could not be opened"))
+  })
 })
 
 test_that("non-existent IPs are detected", {
@@ -51,6 +53,12 @@ test_that("Longitude, latitude, and geoname_id can be retrieved", {
   }
 })
 
+test_that("Postcodes can be retrieved", {
+    infile <- system.file("extdata", "GeoIP2-City-Test.mmdb", package = "rgeolocate")
+    results <- maxmind("2.125.160.216", infile, "postcode")
+    expect_that(results$postcode[1], equals("OX1"))
+})
+
 
 test_that("Unknown longitude, latitude and geoname_id are returned as NA", {
   test_files <- c("GeoIP2-Anonymous-IP-Test.mmdb",
